@@ -27,7 +27,7 @@ class PackagekitJob : public Plasma::ServiceJob
 {
     Q_OBJECT
 public:
-    PackagekitJob(const QString& destination, const QString& operation, const QMap< QString, QVariant >& parameters, QObject* parent = 0);
+    PackagekitJob(const QString& destination, const QString& operation, const QMap< QString, QVariant >& parameters, QObject* parent = nullptr);
     ~PackagekitJob() override;
 
 protected:
