@@ -37,8 +37,8 @@ private Q_SLOTS:
 void HistoryTest::testSetMaxSize()
 {
     QScopedPointer<History> history(new History(nullptr));
-    QSignalSpy changedSpy(history.data(), SIGNAL(changed()));
-    QSignalSpy topSpy(history.data(), SIGNAL(topChanged()));
+    QSignalSpy changedSpy(history.data(), &History::changed);
+    QSignalSpy topSpy(history.data(), &History::topChanged);
     QVERIFY(history->empty());
     QCOMPARE(history->maxSize(), 0u);
     QVERIFY(changedSpy.isEmpty());
@@ -86,8 +86,8 @@ void HistoryTest::testSetMaxSize()
 void HistoryTest::testInsertRemove()
 {
     QScopedPointer<History> history(new History(nullptr));
-    QSignalSpy topSpy(history.data(), SIGNAL(topChanged()));
-    QSignalSpy topUserSelectedSpy(history.data(), SIGNAL(topIsUserSelectedSet()));
+    QSignalSpy topSpy(history.data(), &History::topChanged);
+    QSignalSpy topUserSelectedSpy(history.data(), &History::topIsUserSelectedSet);
 
     history->setMaxSize(10);
     QVERIFY(history->empty());
@@ -228,7 +228,7 @@ void HistoryTest::testClear()
     QVERIFY(history->first());
 
     // and clear
-    QSignalSpy topSpy(history.data(), SIGNAL(topChanged()));
+    QSignalSpy topSpy(history.data(), &History::topChanged);
     QVERIFY(topSpy.isEmpty());
     history->slotClear();
     QVERIFY(history->empty());
@@ -259,7 +259,7 @@ void HistoryTest::testFind()
 void HistoryTest::testCycle()
 {
     QScopedPointer<History> history(new History(nullptr));
-    QSignalSpy topSpy(history.data(), SIGNAL(topChanged()));
+    QSignalSpy topSpy(history.data(), &History::topChanged);
     history->setMaxSize(10);
     QVERIFY(!history->nextInCycle());
     QVERIFY(!history->prevInCycle());
