@@ -33,6 +33,8 @@
 
 #include <unistd.h>
 
+#include <updatelaunchenvjob.h>
+
 #include "startplasma.h"
 
 QTextStream out(stderr);
@@ -208,7 +210,7 @@ void runEnvironmentScripts()
             continue;
         }
         const auto dirScripts = dir.entryInfoList({QStringLiteral("*.sh")}, QDir::Files, QDir::Name);
-        for (const auto script : dirScripts) {
+        for (const auto &script : dirScripts) {
             scripts << script.absoluteFilePath();
         }
     }
@@ -284,14 +286,9 @@ void cleanupPlasmaEnvironment()
 // In that case, the update in startplasma might be too late.
 bool syncDBusEnvironment()
 {
-    int exitCode;
     // At this point all environment variables are set, let's send it to the DBus session server to update the activation environment
-    if (!QStandardPaths::findExecutable(QStringLiteral("dbus-update-activation-environment")).isEmpty()) {
-        exitCode = runSync(QStringLiteral("dbus-update-activation-environment"), { QStringLiteral("--systemd"), QStringLiteral("--all") });
-    } else {
-        exitCode = runSync(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR "/ksyncdbusenv"), {});
-    }
-    return exitCode == 0;
+    auto job =  new UpdateLaunchEnvJob(QProcessEnvironment::systemEnvironment());
+    return job->exec();
 }
 
 void setupFontDpi()
@@ -334,17 +331,6 @@ QProcess* setupKSplash()
     return p;
 }
 
-void setupGSLib()
-// Get Ghostscript to look into user's KDE fonts dir for additional Fontmap
-{
-    const QByteArray usr_fdir = QFile::encodeName(QDir::home().absoluteFilePath(QStringLiteral(".fonts")));
-    if (qEnvironmentVariableIsSet("GS_LIB")) {
-        qputenv("GS_LIB", usr_fdir + ':' + qgetenv("GS_LIB"));
-    } else {
-        qputenv("GS_LIB", usr_fdir);
-    }
-}
-
 bool startPlasmaSession(bool wayland)
 {
     OrgKdeKSplashInterface iface(QStringLiteral("org.kde.KSplash"), QStringLiteral("/KSplash"), QDBusConnection::sessionBus());
